@@ -63,7 +63,8 @@ Feed *AddFeedDialog::feed() const
 }
 
 AddFeedDialog::AddFeedDialog(QWidget *parent, const QString &name)
-    : QDialog(parent), m_feed(0)
+    : QDialog(parent)
+    , m_feed(0)
 {
     setObjectName(name);
     setWindowTitle(i18n("Add Feed"));
@@ -86,7 +87,8 @@ AddFeedDialog::AddFeedDialog(QWidget *parent, const QString &name)
 }
 
 AddFeedDialog::~AddFeedDialog()
-{}
+{
+}
 
 void AddFeedDialog::setUrl(const QString &t)
 {
@@ -106,7 +108,7 @@ void AddFeedDialog::accept()
         feedUrl = feedUrl.right(feedUrl.length() - 5);
     }
 
-    if (feedUrl.indexOf(QStringLiteral(":/")) == -1) {
+    if (!feedUrl.contains(QStringLiteral(":/"))) {
         feedUrl.prepend(QStringLiteral("http://"));
     }
 
