@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,19 +26,16 @@
 class QPrinter;
 class KActionCollection;
 
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class SlideContainer;
 class TextToSpeechWidget;
 }
 
-namespace WebEngineViewer
-{
+namespace WebEngineViewer {
 class FindBarWebEngineView;
 }
 
-namespace Akregator
-{
+namespace Akregator {
 class AKREGATOR_EXPORT ArticleViewerWebEngineWidgetNg : public QWidget
 {
     Q_OBJECT
