@@ -32,9 +32,7 @@
 
 #include <QWidget>
 
-namespace Akregator
-{
-
+namespace Akregator {
 class FeedPropertiesWidget : public QWidget, public Ui::FeedPropertiesWidgetBase
 {
     Q_OBJECT
@@ -69,7 +67,7 @@ public:
 
 public Q_SLOTS:
 
-    void accept() Q_DECL_OVERRIDE;
+    void accept() override;
 
 protected:
     QString feedName() const;
@@ -101,8 +99,6 @@ private:
 private Q_SLOTS:
     void slotSetWindowTitle(const QString &);
 };
-
 } // namespace Akregator
 
 #endif // AKREGATOR_FEEDPROPERTIESDIALOG_H
-
