@@ -22,8 +22,7 @@
 
 #include "frame.h"
 #include "config-akregator.h"
-namespace Akregator
-{
+namespace Akregator {
 class ArticleViewerWidget;
 class AKREGATOR_EXPORT MainFrame : public Frame
 {
@@ -34,15 +33,16 @@ public:
     explicit MainFrame(QWidget *parent, QWidget *widget);
     virtual ~MainFrame();
 
-    QUrl url() const Q_DECL_OVERRIDE;
+    QUrl url() const override;
 
-    bool openUrl(const OpenUrlRequest &) Q_DECL_OVERRIDE {
+    bool openUrl(const OpenUrlRequest &) override
+    {
         return false;
     }
 
     void setArticleViewer(Akregator::ArticleViewerWidget *articleViewer);
 
-    qreal zoomFactor() const Q_DECL_OVERRIDE;
+    qreal zoomFactor() const override;
 
 public Q_SLOTS:
     void slotCopyLinkAsInFrame(int frameId);
@@ -59,7 +59,6 @@ public Q_SLOTS:
 private:
     Akregator::ArticleViewerWidget *mArticleViewer;
 };
-
 } // namespace Akregator
 
 #endif // MAINFRAME_H
